@@ -20,6 +20,7 @@ function SciMLBase.__init(prob::SciMLBase.AbstractDDEProblem,
         save_start = save_everystep || isempty(saveat) ||
                      saveat isa Number || prob.tspan[1] in saveat,
         save_end = nothing,
+        save_discretes = true,
         callback = nothing,
         dense = save_everystep && isempty(saveat),
         calck = (callback !== nothing && callback != CallbackSet()) || # Empty callback
@@ -297,6 +298,7 @@ function SciMLBase.__init(prob::SciMLBase.AbstractDDEProblem,
         save_on,
         save_start,
         save_end,
+        save_discretes,
         save_end_user,
         callback_set,
         isoutofdomain,
